pub fn parse_command(input: &str) -> Result<CardinalCommand, ParseError>Expand description
Parse a Cardinal command line.
The leading : is optional so that the parser remains convenient in tests
and non-interactive CLI tooling.
pub fn parse_command(input: &str) -> Result<CardinalCommand, ParseError>Parse a Cardinal command line.
The leading : is optional so that the parser remains convenient in tests
and non-interactive CLI tooling.